@@ -45,9 +45,7 @@
 #include <libedata-book/e-book-backend-cache.h>
 #include "e-book-backend-webdav.h"
 
-#include <libsoup/soup-uri.h>
-#include <libsoup/soup-session-sync.h>
-#include <libsoup/soup-auth.h>
+#include <libsoup/soup.h>
 
 #include <libxml/parser.h>
 #include <libxml/xmlreader.h>
@@ -77,6 +75,31 @@ typedef struct {
 	EFlag              *running;
 } WebdavBackendSearchClosure;
 
+static void
+webdav_debug_setup (SoupSession *session)
+{
+	const gchar *debug_str;
+	SoupLogger *logger;
+	SoupLoggerLogLevel level;
+
+	g_return_if_fail (session != NULL);
+
+	debug_str = g_getenv ("WEBDAV_DEBUG");
+	if (!debug_str || !*debug_str)
+		return;
+
+	if (g_ascii_strcasecmp (debug_str, "all") == 0)
+		level = SOUP_LOGGER_LOG_BODY;
+	else if (g_ascii_strcasecmp (debug_str, "headers") == 0)
+		level = SOUP_LOGGER_LOG_HEADERS;
+	else
+		level = SOUP_LOGGER_LOG_MINIMAL;
+
+	logger = soup_logger_new (level, 100 * 1024 * 1024);
+	soup_session_add_feature (session, SOUP_SESSION_FEATURE (logger));
+	g_object_unref (logger);
+}
+
 static void
 closure_destroy(WebdavBackendSearchClosure *closure)
 {
@@ -109,7 +132,6 @@ static EContact*
 download_contact(EBookBackendWebdav *webdav, const gchar *uri)
 {
 	SoupMessage *message;
-	const gchar  *content_type;
 	const gchar  *etag;
 	EContact    *contact;
 	guint        status;
@@ -124,19 +146,14 @@ download_contact(EBookBackendWebdav *webdav, const gchar *uri)
 		g_object_unref(message);
 		return NULL;
 	}
-	/* TODO: write a real Content-Type parser,
-	 * DECIDE: should we also accept text/plain for webdav servers that
-	 * don't know about text/x-vcard?*/
-	content_type = soup_message_headers_get(message->response_headers,
-						"Content-Type");
-	if (content_type != NULL && strstr(content_type, "text/x-vcard") == NULL) {
-		g_message("'%s' doesn't have mime-type text/x-vcard but '%s'", uri,
-			  content_type);
+
+	if (message->response_body == NULL) {
+		g_message("no response body after requesting '%s'", uri);
 		g_object_unref(message);
 		return NULL;
 	}
-	if (message->response_body == NULL) {
-		g_message("no response body after requesting '%s'", uri);
+
+	if (message->response_body->length <= 11 || 0 != g_ascii_strncasecmp ((const gchar *) message->response_body->data, "BEGIN:VCARD", 11)) {
 		g_object_unref(message);
 		return NULL;
 	}
@@ -168,7 +185,7 @@ upload_contact(EBookBackendWebdav *webdav, EContact *contact)
 	SoupMessage *message;
 	gchar       *uri;
 	gchar       *etag;
-	const gchar  *new_etag;
+	const gchar  *new_etag, *redir_uri;
 	gchar        *request;
 	guint        status;
 	const gchar  *property;
@@ -219,9 +236,29 @@ upload_contact(EBookBackendWebdav *webdav, EContact *contact)
 	status   = soup_session_send_message(webdav->priv->session, message);
 	new_etag = soup_message_headers_get(message->response_headers, "ETag");
 
+	redir_uri = soup_message_headers_get (message->response_headers, "Location");
+
 	/* set UID and REV fields */
 	e_contact_set(contact, E_CONTACT_REV, (gconstpointer) new_etag);
-	e_contact_set(contact, E_CONTACT_UID, uri);
+	if (redir_uri && *redir_uri) {
+		if (!strstr (redir_uri, "://")) {
+			/* it's a relative URI */
+			SoupURI *suri = soup_uri_new (uri);
+			gchar *full_uri;
+
+			soup_uri_set_path (suri, redir_uri);
+			full_uri = soup_uri_to_string (suri, TRUE);
+
+			e_contact_set (contact, E_CONTACT_UID, full_uri);
+
+			g_free (full_uri);
+			soup_uri_free (suri);
+		} else {
+			e_contact_set (contact, E_CONTACT_UID, redir_uri);
+		}
+	} else {
+		e_contact_set (contact, E_CONTACT_UID, uri);
+	}
 
 	g_object_unref(message);
 	g_free(request);
@@ -292,10 +329,12 @@ e_book_backend_webdav_create_contact(EBookBackend *backend,
 	}
 	/* PUT request didn't return an etag? try downloading to get one */
 	if (e_contact_get_const(contact, E_CONTACT_REV) == NULL) {
+		const gchar *new_uid;
 		EContact *new_contact;
 
 		g_warning("Server didn't return etag for new address resource");
-		new_contact = download_contact(webdav, uid);
+		new_uid = e_contact_get_const (contact, E_CONTACT_UID);
+		new_contact = download_contact (webdav, new_uid);
 		g_object_unref(contact);
 
 		if (new_contact == NULL) {
@@ -987,13 +1026,11 @@ e_book_backend_webdav_load_source(EBookBackend *backend,
 {
 	EBookBackendWebdav        *webdav = E_BOOK_BACKEND_WEBDAV(backend);
 	EBookBackendWebdavPrivate *priv   = webdav->priv;
-	const gchar               *uri;
-	const gchar                *offline;
-	const gchar                *uri_without_protocol;
-	const gchar                *protocol;
-	const gchar                *use_ssl;
-	const gchar                *suffix;
+	gchar                     *uri;
+	const gchar               *offline;
+	const gchar               *use_ssl;
 	SoupSession               *session;
+	SoupURI                   *suri;
 
 	uri = e_source_get_uri(source);
 	if (uri == NULL) {
@@ -1001,35 +1038,65 @@ e_book_backend_webdav_load_source(EBookBackend *backend,
 		return  GNOME_Evolution_Addressbook_OtherError;
 	}
 
+	suri = soup_uri_new (uri);
+	g_free (uri);
+
+	if (!suri) {
+		g_warning ("invalid uri given for addressbook");
+		return  GNOME_Evolution_Addressbook_OtherError;
+	}
+
 	offline = e_source_get_property(source, "offline_sync");
 	if (offline && g_str_equal(offline, "1"))
 		priv->marked_for_offline = TRUE;
 
 	if (priv->mode == GNOME_Evolution_Addressbook_MODE_LOCAL
 			&& !priv->marked_for_offline ) {
+		soup_uri_free (suri);
 		return GNOME_Evolution_Addressbook_OfflineUnavailable;
 	}
 
-	if (strncmp(uri, "webdav://", 9) != 0) {
+	if (!suri->scheme || !g_str_equal (suri->scheme, "webdav")) {
 		/* the book is not for us */
+		soup_uri_free (suri);
 		return GNOME_Evolution_Addressbook_OtherError;
 	}
 
-	uri_without_protocol = uri + 9;
-	use_ssl              = e_source_get_property(source, "use_ssl");
-	if (use_ssl != NULL && strcmp(use_ssl, "1") == 0) {
-		protocol = "https://";
+	use_ssl = e_source_get_property (source, "use_ssl");
+	if (use_ssl != NULL && strcmp (use_ssl, "1") == 0) {
+		soup_uri_set_scheme (suri, "https");
 	} else {
-		protocol = "http://";
+		soup_uri_set_scheme (suri, "https");
 	}
 
 	/* append slash if missing */
-	suffix = "";
-	if (uri_without_protocol[strlen(uri_without_protocol) - 1] != '/')
-		suffix = "/";
+	if (!suri->path || !*suri->path || suri->path[strlen (suri->path) - 1] != '/') {
+		gchar *new_path = g_strconcat (suri->path ? suri->path : "", "/", NULL);
+		soup_uri_set_path (suri, new_path);
+		g_free (new_path);
+	}
 
-	priv->uri
-		= g_strdup_printf("%s%s%s", protocol, uri_without_protocol, suffix);
+	if (suri->host && strchr (suri->host, '@')) {
+		gchar *at = strchr (suri->host, '@');
+		gchar *new_user;
+
+		*at = '\0';
+
+		new_user = g_strconcat (suri->user ? suri->user : "", "@", suri->host, NULL);
+
+		*at = '@';
+
+		soup_uri_set_host (suri, at + 1);
+		soup_uri_set_user (suri, new_user);
+
+		g_free (new_user);
+	}
+
+	priv->uri = soup_uri_to_string (suri, FALSE);
+	if (!priv->uri) {
+		soup_uri_free (suri);
+		return GNOME_Evolution_Addressbook_OtherError;
+	}
 
 	priv->cache = e_book_backend_cache_new(priv->uri);
 
@@ -1042,6 +1109,7 @@ e_book_backend_webdav_load_source(EBookBackend *backend,
 	e_proxy_setup_proxy (priv->proxy);
 	g_signal_connect (priv->proxy, "changed", G_CALLBACK (proxy_settings_changed), priv);
 	proxy_settings_changed (priv->proxy, priv);
+	webdav_debug_setup (priv->session);
 
 	e_book_backend_notify_auth_required(backend);
 	e_book_backend_set_is_loaded(backend, TRUE);
@@ -1049,6 +1117,8 @@ e_book_backend_webdav_load_source(EBookBackend *backend,
 	e_book_backend_set_is_writable(backend, TRUE);
 	e_book_backend_notify_writable(backend, TRUE);
 
+	soup_uri_free (suri);
+
 	return GNOME_Evolution_Addressbook_Success;
 }
 
