@@ -48,6 +48,8 @@
 
 #define d(x)
 
+G_DEFINE_TYPE (EDestination, e_destination, G_TYPE_OBJECT)
+
 struct _EDestinationPrivate {
 	gchar *raw;
 
@@ -157,36 +159,12 @@ e_destination_init (EDestination *dest)
 	dest->priv->ignored = FALSE;
 }
 
-GType
-e_destination_get_type (void)
-{
-	static GType dest_type = 0;
-
-	if (!dest_type) {
-		GTypeInfo dest_info = {
-			sizeof (EDestinationClass),
-			NULL, /* base_class_init */
-			NULL, /* base_class_finalize */
-			(GClassInitFunc)  e_destination_class_init,
-			NULL, /* class_finalize */
-			NULL, /* class_data */
-			sizeof (EDestination),
-			0,    /* n_preallocs */
-			(GInstanceInitFunc) e_destination_init
-		};
-
-		dest_type = g_type_register_static (G_TYPE_OBJECT, "EDestination", &dest_info, 0);
-	}
-
-	return dest_type;
-}
-
 /**
  * e_destination_new:
  *
  * Creates a new #EDestination with blank values.
  *
- * Return value: A newly created #EDestination.
+ * Returns: A newly created #EDestination.
  **/
 EDestination *
 e_destination_new (void)
@@ -200,7 +178,7 @@ e_destination_new (void)
  *
  * Creates a new #EDestination identical to @dest.
  *
- * Return value: A newly created #EDestination, identical to @dest.
+ * Returns: A newly created #EDestination, identical to @dest.
  */
 EDestination*
 e_destination_copy (const EDestination *dest)
@@ -294,7 +272,7 @@ nonempty (const gchar *s)
  *
  * Checks if @dest is blank.
  *
- * Return value: %TRUE if @dest is empty, %FALSE otherwise.
+ * Returns: %TRUE if @dest is empty, %FALSE otherwise.
  */
 gboolean
 e_destination_empty (const EDestination *dest)
@@ -323,7 +301,7 @@ e_destination_empty (const EDestination *dest)
  *
  * Checks if @a and @b are equal.
  *
- * Return value: %TRUE if the destinations are equal, %FALSE otherwise.
+ * Returns: %TRUE if the destinations are equal, %FALSE otherwise.
  **/
 gboolean
 e_destination_equal (const EDestination *a, const EDestination *b)
@@ -630,7 +608,7 @@ e_destination_from_contact (const EDestination *dest)
  * it was not explicitly specified by the user. This can be used
  * to hide it from some UI elements.
  *
- * Return value: %TRUE if destination is an auto recipient, %FALSE otherwise.
+ * Returns: %TRUE if destination is an auto recipient, %FALSE otherwise.
  **/
 gboolean
 e_destination_is_auto_recipient (const EDestination *dest)
@@ -665,7 +643,7 @@ e_destination_set_auto_recipient (EDestination *dest, gboolean value)
  *
  * Gets the contact @dest is pointing to, if any.
  *
- * Return value: An #EContact, or %NULL if none was set.
+ * Returns: An #EContact, or %NULL if none was set.
  **/
 EContact *
 e_destination_get_contact (const EDestination *dest)
@@ -681,7 +659,7 @@ e_destination_get_contact (const EDestination *dest)
  *
  * Gets the unique contact ID @dest is pointing to, if any.
  *
- * Return value: A unique contact ID, or %NULL if none was set.
+ * Returns: A unique contact ID, or %NULL if none was set.
  */
 const gchar *
 e_destination_get_contact_uid (const EDestination *dest)
@@ -698,7 +676,7 @@ e_destination_get_contact_uid (const EDestination *dest)
  * Gets the unique source ID @dest is pointing to, if any. The source
  * ID specifies which address book @dest's contact came from.
  *
- * Return value: A unique source ID, or %NULL if none was set.
+ * Returns: A unique source ID, or %NULL if none was set.
  */
 const gchar *
 e_destination_get_source_uid (const EDestination *dest)
@@ -715,7 +693,7 @@ e_destination_get_source_uid (const EDestination *dest)
  * Gets the index of the e-mail address of the contact that
  * @dest is pointing to, if any.
  *
- * Return value: The e-mail index, or -1 if none was set.
+ * Returns: The e-mail index, or -1 if none was set.
  **/
 gint
 e_destination_get_email_num (const EDestination *dest)
@@ -735,7 +713,7 @@ e_destination_get_email_num (const EDestination *dest)
  * Gets the full name of @dest's addressee, or if the addressee is
  * a contact list, the name the list was filed under.
  *
- * Return value: The full name of the addressee, or %NULL if none was set.
+ * Returns: The full name of the addressee, or %NULL if none was set.
  **/
 const gchar *
 e_destination_get_name (const EDestination *dest)
@@ -786,7 +764,7 @@ e_destination_get_name (const EDestination *dest)
  *
  * Check if @dest is to be ignored.
  *
- * Return value: #TRUE if this destination should be ignored, else #FALSE.
+ * Returns: #TRUE if this destination should be ignored, else #FALSE.
  */
 gboolean
 e_destination_is_ignored (const EDestination *dest)
@@ -813,7 +791,7 @@ e_destination_set_ignored (EDestination *dest, gboolean ignored)
  *
  * Gets the e-mail address of @dest's addressee.
  *
- * Return value: An e-mail address, or an empty string if none was set.
+ * Returns: An e-mail address, or an empty string if none was set.
  **/
 const gchar *
 e_destination_get_email (const EDestination *dest)
@@ -864,10 +842,12 @@ e_destination_get_email (const EDestination *dest)
  * e_destination_get_address:
  * @dest: an #EDestination
  *
- * Gets the formatted name and e-mail address, or in the case of
- * lists, the formatted list of e-mail addresses, from @dest.
+ * Gets the encoded name and email address, or in the case of lists, the
+ * encoded list of email addresses, from @dest.  The returned string is
+ * suitable for use in an email header, but not for displaying to users.
  *
- * Return value: A formatted destination string, or %NULL if the destination was empty.
+ * Returns: an encoded destination string suitable for use in an
+ *          email header, or %NULL if the destination was empty
  **/
 const gchar *
 e_destination_get_address (const EDestination *dest)
@@ -962,7 +942,7 @@ e_destination_set_raw (EDestination *dest, const gchar *raw)
  * Generates a textual representation of @dest, suitable for referring
  * to the destination during user interaction.
  *
- * Return value: A textual representation of the destination.
+ * Returns: A textual representation of the destination.
  **/
 const gchar *
 e_destination_get_textrep (const EDestination *dest, gboolean include_email)
@@ -1005,7 +985,7 @@ e_destination_get_textrep (const EDestination *dest, gboolean include_email)
  *
  * Checks if @dest is a list of addresses.
  *
- * Return value: %TRUE if destination is a list, %FALSE if it is an individual.
+ * Returns: %TRUE if destination is a list, %FALSE if it is an individual.
  **/
 gboolean
 e_destination_is_evolution_list (const EDestination *dest)
@@ -1022,7 +1002,7 @@ e_destination_is_evolution_list (const EDestination *dest)
  * If @dest is a list, checks if the addresses in the list
  * should be presented to the user during interaction.
  *
- * Return value: %TRUE if addresses should be shown, %FALSE otherwise.
+ * Returns: %TRUE if addresses should be shown, %FALSE otherwise.
  **/
 gboolean
 e_destination_list_show_addresses (const EDestination *dest)
@@ -1042,7 +1022,7 @@ e_destination_list_show_addresses (const EDestination *dest)
  * If @dest is a list, gets the list of destinations. The list
  * and its elements belong to @dest, and should not be freed.
  *
- * Return value: A list of elements of type #EDestination, or %NULL.
+ * Returns: A list of elements of type #EDestination, or %NULL.
  **/
 const GList *
 e_destination_list_get_dests (const EDestination *dest)
@@ -1061,7 +1041,7 @@ e_destination_list_get_dests (const EDestination *dest)
  *
  * Check if @dest wants to get mail formatted as HTML.
  *
- * Return value: %TRUE if destination wants HTML, %FALSE if not.
+ * Returns: %TRUE if destination wants HTML, %FALSE if not.
  **/
 gboolean
 e_destination_get_html_mail_pref (const EDestination *dest)
@@ -1105,7 +1085,7 @@ e_destination_set_html_mail_pref (EDestination *dest, gboolean flag)
  * Generates a joint text representation of all the #EDestination
  * elements in @destv.
  *
- * Return value: The text representation of @destv.
+ * Returns: The text representation of @destv.
  **/
 gchar *
 e_destination_get_textrepv (EDestination **destv)
@@ -1149,7 +1129,7 @@ e_destination_get_textrepv (EDestination **destv)
  *
  * Generates an XML tree from @dest.
  *
- * Return value: Pointer to the root node of the XML tree.
+ * Returns: Pointer to the root node of the XML tree.
  **/
 static xmlNodePtr
 e_destination_xml_encode (const EDestination *dest)
@@ -1232,7 +1212,7 @@ e_destination_xml_encode (const EDestination *dest)
  * Initializes @dest based on the information encoded in the
  * XML tree under @node.
  *
- * Return value: %TRUE if the XML tree was well-formed, %FALSE otherwise.
+ * Returns: %TRUE if the XML tree was well-formed, %FALSE otherwise.
  **/
 static gboolean
 e_destination_xml_decode (EDestination *dest, xmlNodePtr node)
@@ -1409,7 +1389,7 @@ null_terminate_and_remove_extra_whitespace (xmlChar *xml_in, gint size)
  *
  * Exports a destination to an XML document.
  *
- * Return value: An XML string, allocated with g_malloc.
+ * Returns: An XML string, allocated with g_malloc.
  **/
 gchar *
 e_destination_export (const EDestination *dest)
@@ -1444,7 +1424,7 @@ e_destination_export (const EDestination *dest)
  *
  * Creates an #EDestination from an XML document.
  *
- * Return value: An #EDestination, or %NULL if the document was not well-formed.
+ * Returns: An #EDestination, or %NULL if the document was not well-formed.
  **/
 EDestination *
 e_destination_import (const gchar *str)
@@ -1474,7 +1454,7 @@ e_destination_import (const gchar *str)
  *
  * Exports multiple #EDestination elements to a single XML document.
  *
- * Return value: An XML string, allocated with g_malloc.
+ * Returns: An XML string, allocated with g_malloc.
  **/
 gchar *
 e_destination_exportv (EDestination **destv)
@@ -1516,7 +1496,7 @@ e_destination_exportv (EDestination **destv)
  * Creates an array of pointers to #EDestination elements
  * from an XML document.
  *
- * Return value: A %NULL-terminated array of pointers to #EDestination elements.
+ * Returns: A %NULL-terminated array of pointers to #EDestination elements.
  **/
 EDestination **
 e_destination_importv (const gchar *str)
