@@ -103,13 +103,13 @@ typedef struct Node {
 	gchar post_token; /* post token to apppend with substitute */
 	gchar rval; /* rhs value for binary ops */
 	gint level; /* depth in the hier */
-	gint prefix:1; /* unary operator to be searched ?*/
-	gint sys_node:1; /* is it a predefined term ? */
-	gint ignore_lhs:1; /* ignore lhs value ?*/
-	gint swap :1;
-	gint prenode :1;
-	gint operator:1;
-	gint execute:1;
+	guint prefix:1; /* unary operator to be searched ?*/
+	guint sys_node:1; /* is it a predefined term ? */
+	guint ignore_lhs:1; /* ignore lhs value ?*/
+	guint swap :1;
+	guint prenode :1;
+	guint operator:1;
+	guint execute:1;
 	gint ref;
 }Node;
 
@@ -199,13 +199,14 @@ escape_values (gchar *str)
 }
 
 /**
- * camel_search_sexp_to_sql:
+ * camel_sexp_to_sql:
  * @txt: A valid sexp expression
  *
  * Converts a valid sexp expression to a sql statement with table fields converted into it.
  * This is very specific to Evolution. It might crash is the sexp is invalid. The callers must ensure that the sexp is valid
+ *
+ * Since: 2.24
  **/
-
 gchar *
 camel_sexp_to_sql (const gchar *txt)
 {
@@ -278,8 +279,8 @@ camel_sexp_to_sql (const gchar *txt)
 
 								if (token != G_TOKEN_LEFT_PAREN) {
 									/* remove #t*/
-									token = g_scanner_get_next_token (scanner);
-									token = g_scanner_get_next_token (scanner);
+									g_scanner_get_next_token (scanner);
+									g_scanner_get_next_token (scanner);
 								}
 
 							}
@@ -501,7 +502,6 @@ camel_sexp_to_sql (const gchar *txt)
 				gint len = 2;
 				Node *pnode;
 
-
 				n1=NULL; n2=NULL; n3=NULL;
 				tmp = operands;
 				n1 = operands->data;
@@ -540,7 +540,6 @@ camel_sexp_to_sql (const gchar *txt)
 					else
 						dyn_lvl = n3->level;
 
-
 					if (n3->prefix && g_ascii_strcasecmp (opnode->token, "=") == 0) {
 						/* see if '=' was a last operator. if so take care of it */
 						free_node(opnode);
@@ -573,7 +572,6 @@ camel_sexp_to_sql (const gchar *txt)
 							dyn_lvl = opnode->level;
 						}
 
-
 					}
 					if (n3->prefix && ((g_ascii_strcasecmp (opnode->token, ">") == 0) || (g_ascii_strcasecmp (opnode->token, ">") == 0) )) {
 						/* see if '=' was a last operator. if so take care of it */
@@ -606,7 +604,6 @@ camel_sexp_to_sql (const gchar *txt)
 							n3->ignore_lhs = 0;
 						}
 
-
 					}
 
 					/* Handle if 'not' was a last sysnode, if so take care of it */
@@ -709,7 +706,6 @@ camel_sexp_to_sql (const gchar *txt)
 			}
 		}
 
-
 	}
 
 	tmp = operands;
@@ -733,7 +729,6 @@ camel_sexp_to_sql (const gchar *txt)
 	d(g_node_dump (all));
 	d(printf("\n\n\n"));
 
-
 	res=NULL;
 	tmp = all;
 	op=NULL; n1=NULL;
@@ -882,7 +877,6 @@ camel_sexp_to_sql (const gchar *txt)
 #ifdef TEST_MAIN
 /*
 
-
 (and (match-all (and (not (system-flag "deleted")) (not (system-flag "junk"))))
  (and   (or
 
