@@ -196,6 +196,11 @@ vee_info_set_user_tag(CamelMessageInfo *mi, const gchar *name, const gchar *valu
 	return res;
 }
 
+/**
+ * camel_vee_summary_load_check_unread_vfolder:
+ *
+ * Since: 2.26
+ **/
 void
 camel_vee_summary_load_check_unread_vfolder (CamelVeeSummary *vs)
 {
@@ -342,14 +347,12 @@ message_info_from_uid (CamelFolderSummary *s, const gchar *uid)
 	/* FIXME[disk-summary] too bad design. Need to peek it from cfs
 	 * instead of hacking ugly like this */
 	CAMEL_SUMMARY_LOCK(s, summary_lock);
-	CAMEL_SUMMARY_LOCK(s, ref_lock);
 
 	info = g_hash_table_lookup (s->loaded_infos, uid);
 
 	if (info)
-		info->refcount++;
+		camel_message_info_ref (info);
 
-	CAMEL_SUMMARY_UNLOCK(s, ref_lock);
 	CAMEL_SUMMARY_UNLOCK(s, summary_lock);
 
 	if (!info) {
@@ -443,7 +446,7 @@ camel_vee_summary_get_type (void)
  * This will create a new CamelVeeSummary object and read in the
  * summary data from disk, if it exists.
  *
- * Return value: A new CamelVeeSummary object.
+ * Returns: A new CamelVeeSummary object.
  **/
 CamelFolderSummary *
 camel_vee_summary_new(CamelFolder *parent)
@@ -465,6 +468,11 @@ camel_vee_summary_new(CamelFolder *parent)
 	return &s->summary;
 }
 
+/**
+ * camel_vee_summary_get_ids:
+ *
+ * Since: 2.24
+ **/
 GPtrArray *
 camel_vee_summary_get_ids (CamelVeeSummary *summary, gchar hash[8])
 {
@@ -503,6 +511,7 @@ camel_vee_summary_add(CamelVeeSummary *s, CamelFolderSummary *summary, const gch
 			camel_object_ref(summary);
 		}
 
+		camel_message_info_ref (mi);
 		return mi;
 	}
 
