@@ -110,9 +110,9 @@ imapx_parse_flags(CamelIMAPXStream *stream, guint32 *flagsp, CamelFlag **user_fl
  * if the flags does not match returns the original one as it is.
  * It will never return NULL, it will return empty string, instead.
  *
- * @param flag Flag to rename.
- * @param len Length of the flag name.
- * @param server_to_evo if TRUE, then converting server names to evo's names, if FALSE then opposite.
+ * @flag: Flag to rename.
+ * @len: Length of the flag name.
+ * @server_to_evo: if TRUE, then converting server names to evo's names, if FALSE then opposite.
  */
 static const gchar *
 rename_label_flag (const gchar *flag, gint len, gboolean server_to_evo)
@@ -144,6 +144,7 @@ imapx_write_flags(CamelStream *stream, guint32 flags, CamelFlag *user_flags, Cam
 /* throws IO exception */
 {
 	gint i;
+	gboolean first = TRUE;
 
 	if (camel_stream_write(stream, "(", 1) == -1) {
 		camel_exception_setv (ex, 1, "io error: %s", strerror(errno));
@@ -154,30 +155,29 @@ imapx_write_flags(CamelStream *stream, guint32 flags, CamelFlag *user_flags, Cam
 		if (flag_table[i].flag & flags) {
 			if (flags & CAMEL_IMAPX_MESSAGE_RECENT)
 				continue;
-
+			if (!first && camel_stream_write(stream, " ", 1) == -1) {
+				camel_exception_setv (ex, 1, "io error: %s", strerror(errno));
+				return;
+			}
+			first = FALSE;
 			if (camel_stream_write (stream, flag_table[i].name, strlen(flag_table[i].name)) == -1) {
 				camel_exception_setv (ex,1, "io error: %s", strerror(errno));
 				return;
 			}
 
 			flags &= ~flag_table[i].flag;
-			if (flags != 0 && user_flags == NULL)
-				if (camel_stream_write(stream, " ", 1) == -1) {
-					camel_exception_setv (ex, 1, "io error: %s", strerror(errno));
-					return;
-				}
 		}
 	}
 
 	while (user_flags) {
 		const gchar *flag_name = rename_label_flag (user_flags->name, strlen (user_flags->name), FALSE);
 
-		if (camel_stream_write(stream, flag_name, strlen (flag_name)) == -1) {
+		if (!first && camel_stream_write(stream, " ", 1) == -1) {
 			camel_exception_setv (ex, 1, "io error: %s", strerror(errno));
 			return;
 		}
-
-		if (user_flags->next && camel_stream_write(stream, " ", 1) == -1) {
+		first = FALSE;
+		if (camel_stream_write(stream, flag_name, strlen (flag_name)) == -1) {
 			camel_exception_setv (ex, 1, "io error: %s", strerror(errno));
 			return;
 		}
@@ -401,6 +401,7 @@ imapx_parse_capability(CamelIMAPXStream *stream, CamelException *ex)
 	struct _capability_info * cinfo;
 
 	cinfo = g_malloc0(sizeof(*cinfo));
+	cinfo->auth_types = g_hash_table_new_full (g_str_hash, g_str_equal, (GDestroyNotify) g_free, NULL);
 
 	/* FIXME: handle auth types */
 	while (!camel_exception_is_set (ex) && (tok = camel_imapx_stream_token(stream, &token, &len, ex)) != '\n') {
@@ -413,6 +414,12 @@ imapx_parse_capability(CamelIMAPXStream *stream, CamelException *ex)
 				p = token;
 				while ((c = *p))
 					*p++ = toupper(c);
+				if (!strncmp ((gchar *) token, "AUTH=", 5)) {
+					g_hash_table_insert (cinfo->auth_types,
+							g_strdup ((gchar *)token + 5),
+							GINT_TO_POINTER (1));
+					break;
+				}
 			case IMAPX_TOK_INT:
 				d(printf(" cap: '%s'\n", token));
 				for (i = 0; i < G_N_ELEMENTS (capa_table); i++)
@@ -440,6 +447,7 @@ imapx_parse_capability(CamelIMAPXStream *stream, CamelException *ex)
 
 void imapx_free_capability(struct _capability_info *cinfo)
 {
+	g_hash_table_destroy (cinfo->auth_types);
 	g_free(cinfo);
 }
 
@@ -475,7 +483,6 @@ imapx_parse_namespace_list (CamelIMAPXStream *stream, CamelException *ex)
 
 				node = g_new0 (CamelIMAPXStoreNamespace, 1);
 				node->next = NULL;
-				node->full_name = g_strdup ((gchar *) token);
 				node->path = g_strdup ((gchar *) token);
 
 				tok = camel_imapx_stream_token (stream, &token, &len, ex);
@@ -508,6 +515,10 @@ imapx_parse_namespace_list (CamelIMAPXStream *stream, CamelException *ex)
 				if (!g_ascii_strncasecmp (node->path, "INBOX", 5) &&
 						(node->path [6] == '\0' || node->path [6] == node->sep ))
 					memcpy (node->path, "INBOX", 5);
+
+				/* TODO remove full_name later. not required */
+				node->full_name = g_strdup (node->path);
+
 				tok = camel_imapx_stream_token (stream, &token, &len, ex);
 				if (tok != ')') {
 					camel_exception_set (ex, 1, "namespace: expected a ')'");
@@ -1738,7 +1749,7 @@ imapx_parse_list(CamelIMAPXStream *is, CamelException *ex)
 	camel_imapx_stream_nstring(is, &token, ex);
 	linfo->separator = token?*token:0;
 	camel_imapx_stream_astring(is, &token, ex);
-	linfo->name = g_strdup((gchar *) token);
+	linfo->name = camel_utf7_utf8 ((gchar *) token);
 
 	return linfo;
 }
