@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /* e-source-group.c
  *
- * Copyright (C) 2003  Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -34,9 +34,9 @@
 /* Private members.  */
 
 struct _ESourceGroupPrivate {
-	char *uid;
-	char *name;
-	char *base_uri;
+	gchar *uid;
+	gchar *name;
+	gchar *base_uri;
 
 	GSList *sources;
 
@@ -46,7 +46,6 @@ struct _ESourceGroupPrivate {
 	GHashTable *properties;
 };
 
-
 /* Signals.  */
 
 enum {
@@ -55,8 +54,7 @@ enum {
 	SOURCE_ADDED,
 	LAST_SIGNAL
 };
-static unsigned int signals[LAST_SIGNAL] = { 0 };
-
+static guint signals[LAST_SIGNAL] = { 0 };
 
 /* Callbacks.  */
 
@@ -64,14 +62,13 @@ static void
 source_changed_callback (ESource *source,
 			 ESourceGroup *group)
 {
-	if (! group->priv->ignore_source_changed)
+	if (!group->priv->ignore_source_changed)
 		g_signal_emit (group, signals[CHANGED], 0);
 }
 
-
 /* GObject methods.  */
 
-G_DEFINE_TYPE (ESourceGroup, e_source_group, G_TYPE_OBJECT);
+G_DEFINE_TYPE (ESourceGroup, e_source_group, G_TYPE_OBJECT)
 
 static void
 impl_dispose (GObject *object)
@@ -113,7 +110,6 @@ impl_finalize (GObject *object)
 	(* G_OBJECT_CLASS (e_source_group_parent_class)->finalize) (object);
 }
 
-
 /* Initialization.  */
 
 static void
@@ -233,8 +229,8 @@ property_dump_cb (const gchar *key, const gchar *value, xmlNodePtr root)
 /* Public methods.  */
 
 ESourceGroup *
-e_source_group_new (const char *name,
-		    const char *base_uri)
+e_source_group_new (const gchar *name,
+		    const gchar *base_uri)
 {
 	ESourceGroup *new;
 
@@ -251,7 +247,7 @@ e_source_group_new (const char *name,
 }
 
 ESourceGroup *
-e_source_group_new_from_xml (const char *xml)
+e_source_group_new_from_xml (const gchar *xml)
 {
 	xmlDocPtr doc;
 	ESourceGroup *group;
@@ -316,6 +312,7 @@ e_source_group_new_from_xmldoc (xmlDocPtr doc)
 			goto done;
 		}
 		e_source_group_add_source (new, new_source, -1);
+		g_object_unref (new_source);
 	}
 
 	e_source_group_set_readonly (new, readonly_str && !strcmp (GC readonly_str, "yes"));
@@ -335,7 +332,7 @@ e_source_group_new_from_xmldoc (xmlDocPtr doc)
 
 gboolean
 e_source_group_update_from_xml (ESourceGroup *group,
-				const char *xml,
+				const gchar *xml,
 				gboolean *changed_return)
 {
 	xmlDocPtr xmldoc;
@@ -344,7 +341,6 @@ e_source_group_update_from_xml (ESourceGroup *group,
 	g_return_val_if_fail (E_IS_SOURCE_GROUP (group), FALSE);
 	g_return_val_if_fail (xml != NULL, FALSE);
 
-
 	xmldoc = xmlParseDoc (XC xml);
 
 	success = e_source_group_update_from_xmldoc (group, xmldoc, changed_return);
@@ -419,7 +415,7 @@ e_source_group_update_from_xmldoc (ESourceGroup *group,
 
 	for (nodep = root->children; nodep != NULL; nodep = nodep->next) {
 		ESource *existing_source;
-		char *uid;
+		gchar *uid;
 
 		if (!nodep->name)
 			continue;
@@ -493,7 +489,7 @@ e_source_group_update_from_xmldoc (ESourceGroup *group,
 			g_signal_handlers_disconnect_by_func (source, source_changed_callback, group);
 		}
 
-		if (! changed && q != NULL) {
+		if (!changed && q != NULL) {
 			if (q->data != p->data)
 				changed = TRUE;
 			q = q->next;
@@ -518,12 +514,12 @@ e_source_group_update_from_xmldoc (ESourceGroup *group,
 	return TRUE;		/* Success. */
 }
 
-char *
+gchar *
 e_source_group_uid_from_xmldoc (xmlDocPtr doc)
 {
 	xmlNodePtr root = doc->children;
 	xmlChar *name;
-	char *retval;
+	gchar *retval;
 
 	if (root && root->name) {
 		if (strcmp (GC root->name, "group") != 0)
@@ -543,7 +539,7 @@ e_source_group_uid_from_xmldoc (xmlDocPtr doc)
 
 void
 e_source_group_set_name (ESourceGroup *group,
-			 const char *name)
+			 const gchar *name)
 {
 	g_return_if_fail (E_IS_SOURCE_GROUP (group));
 	g_return_if_fail (name != NULL);
@@ -562,7 +558,7 @@ e_source_group_set_name (ESourceGroup *group,
 }
 
 void e_source_group_set_base_uri (ESourceGroup *group,
-				  const char *base_uri)
+				  const gchar *base_uri)
 {
 	g_return_if_fail (E_IS_SOURCE_GROUP (group));
 	g_return_if_fail (base_uri != NULL);
@@ -599,7 +595,7 @@ void e_source_group_set_readonly (ESourceGroup *group,
 	g_signal_emit (group, signals[CHANGED], 0);
 }
 
-const char *
+const gchar *
 e_source_group_peek_uid (ESourceGroup *group)
 {
 	g_return_val_if_fail (E_IS_SOURCE_GROUP (group), NULL);
@@ -607,7 +603,7 @@ e_source_group_peek_uid (ESourceGroup *group)
 	return group->priv->uid;
 }
 
-const char *
+const gchar *
 e_source_group_peek_name (ESourceGroup *group)
 {
 	g_return_val_if_fail (E_IS_SOURCE_GROUP (group), NULL);
@@ -615,7 +611,7 @@ e_source_group_peek_name (ESourceGroup *group)
 	return group->priv->name;
 }
 
-const char *
+const gchar *
 e_source_group_peek_base_uri (ESourceGroup *group)
 {
 	g_return_val_if_fail (E_IS_SOURCE_GROUP (group), NULL);
@@ -641,7 +637,7 @@ e_source_group_peek_sources (ESourceGroup *group)
 
 ESource *
 e_source_group_peek_source_by_uid (ESourceGroup *group,
-				   const char *uid)
+				   const gchar *uid)
 {
 	GSList *p;
 
@@ -655,7 +651,7 @@ e_source_group_peek_source_by_uid (ESourceGroup *group,
 
 ESource *
 e_source_group_peek_source_by_name (ESourceGroup *group,
-				    const char *name)
+				    const gchar *name)
 {
 	GSList *p;
 
@@ -670,7 +666,7 @@ e_source_group_peek_source_by_name (ESourceGroup *group,
 gboolean
 e_source_group_add_source (ESourceGroup *group,
 			   ESource *source,
-			   int position)
+			   gint position)
 {
 	g_return_val_if_fail (E_IS_SOURCE_GROUP (group), FALSE);
 
@@ -713,6 +709,7 @@ e_source_group_remove_source (ESourceGroup *group,
 							      group);
 			g_signal_emit (group, signals[SOURCE_REMOVED], 0, source);
 			g_signal_emit (group, signals[CHANGED], 0);
+			g_object_unref (source);
 			return TRUE;
 		}
 	}
@@ -722,7 +719,7 @@ e_source_group_remove_source (ESourceGroup *group,
 
 gboolean
 e_source_group_remove_source_by_uid (ESourceGroup *group,
-				     const char *uid)
+				     const gchar *uid)
 {
 	GSList *p;
 
@@ -742,6 +739,7 @@ e_source_group_remove_source_by_uid (ESourceGroup *group,
 							      group);
 			g_signal_emit (group, signals[SOURCE_REMOVED], 0, source);
 			g_signal_emit (group, signals[CHANGED], 0);
+			g_object_unref (source);
 			return TRUE;
 		}
 	}
@@ -749,15 +747,14 @@ e_source_group_remove_source_by_uid (ESourceGroup *group,
 	return FALSE;
 }
 
-
-char *
+gchar *
 e_source_group_to_xml (ESourceGroup *group)
 {
 	xmlDocPtr doc;
 	xmlNodePtr root;
 	xmlChar *xml_buffer;
-	char *returned_buffer;
-	int xml_buffer_size;
+	gchar *returned_buffer;
+	gint xml_buffer_size;
 	GSList *p;
 
 	doc = xmlNewDoc (XC "1.0");
@@ -791,9 +788,115 @@ e_source_group_to_xml (ESourceGroup *group)
 	return returned_buffer;
 }
 
+static gint
+find_esource_from_uid (gconstpointer a, gconstpointer b)
+{
+	return g_ascii_strcasecmp (e_source_peek_uid ((ESource *)(a)), (gchar *)(b));
+}
+
+static gboolean
+compare_source_lists (GSList *a, GSList *b)
+{
+	gboolean retval = TRUE;
+	GSList *l;
+
+	if (g_slist_length(a) != g_slist_length(b))
+		return FALSE;
+
+	for (l = a; l != NULL && retval; l = l->next) {
+		GSList *elem = g_slist_find_custom (b, e_source_peek_uid ((ESource *)(l->data)), (GCompareFunc) find_esource_from_uid);
+
+		if (!elem || !e_source_equal ((ESource *)(l->data), (ESource *)(elem->data)))
+			retval = FALSE;
+	}
+
+	return retval;
+}
+
+/**
+ * e_source_group_equal:
+ * @a: An ESourceGroup
+ * @b: Another ESourceGroup
+ *
+ * Compares if @a is equivalent to @b.
+ *
+ * Returns: %TRUE if @a is equivalent to @b,
+ * %FALSE otherwise.
+ *
+ * Since: 2.24
+ **/
+gboolean
+e_source_group_equal (ESourceGroup *a, ESourceGroup *b)
+{
+	g_return_val_if_fail (E_IS_SOURCE_GROUP (a), FALSE);
+	g_return_val_if_fail (E_IS_SOURCE_GROUP (b), FALSE);
+
+	/* Compare group stuff */
+	if (a->priv->uid
+	 && b->priv->uid
+	 && g_ascii_strcasecmp (a->priv->uid, b->priv->uid))
+		return FALSE;
+
+	if (a->priv->name
+	 && b->priv->name
+	 && g_ascii_strcasecmp (a->priv->name, b->priv->name))
+		return FALSE;
+
+	if (a->priv->base_uri
+	 && b->priv->base_uri
+	 && g_ascii_strcasecmp (a->priv->base_uri, b->priv->base_uri))
+		return FALSE;
+
+	if (a->priv->readonly != b->priv->readonly)
+		return FALSE;
+
+	if (!compare_str_hashes (a->priv->properties, b->priv->properties))
+		return FALSE;
+
+	/* Compare ESources in the groups */
+	if (!compare_source_lists (a->priv->sources, b->priv->sources))
+		return FALSE;
+
+	return TRUE;
+}
+
+/**
+ * e_source_group_xmlstr_equal:
+ * @a: XML representation of an ESourceGroup
+ * @b: XML representation of another ESourceGroup
+ *
+ * Compares if @a is equivalent to @b.
+ *
+ * Returns: %TRUE if @a is equivalent to @b,
+ * %FALSE otherwise.
+ *
+ * Since: 2.24
+ **/
+gboolean
+e_source_group_xmlstr_equal (const gchar *a, const gchar *b)
+{
+	ESourceGroup *grpa, *grpb;
+	gboolean retval;
+
+	grpa = e_source_group_new_from_xml (a);
+	grpb = e_source_group_new_from_xml (b);
+
+	retval = e_source_group_equal (grpa, grpb);
+
+	g_object_unref (grpa);
+	g_object_unref (grpb);
+
+	return retval;
+}
+
+/**
+ * e_source_group_get_property:
+ *
+ * Since: 1.12
+ **/
 gchar *
 e_source_group_get_property (ESourceGroup *source_group,
-		             const gchar *property)
+			     const gchar *property)
 {
 	ESourceGroupPrivate *priv;
 
@@ -803,10 +906,15 @@ e_source_group_get_property (ESourceGroup *source_group,
 	return g_strdup (g_hash_table_lookup (priv->properties, property));
 }
 
+/**
+ * e_source_group_set_property:
+ *
+ * Since: 1.12
+ **/
 void
 e_source_group_set_property (ESourceGroup *source_group,
-		             const gchar *property,
-		             const gchar *value)
+			     const gchar *property,
+			     const gchar *value)
 {
 	ESourceGroupPrivate *priv;
 
@@ -821,6 +929,11 @@ e_source_group_set_property (ESourceGroup *source_group,
 	g_signal_emit (source_group, signals[CHANGED], 0);
 }
 
+/**
+ * e_source_group_foreach_property:
+ *
+ * Since: 1.12
+ **/
 void
 e_source_group_foreach_property (ESourceGroup *source_group, GHFunc func, gpointer data)
 {
