@@ -36,9 +36,11 @@ G_STMT_START {                                            \
 	(iter)->user_data = GINT_TO_POINTER (index);        \
 } G_STMT_END
 
-static void         e_contact_store_init            (EContactStore      *contact_store);
-static void         e_contact_store_class_init      (EContactStoreClass *class);
-static void         e_contact_store_tree_model_init (GtkTreeModelIface  *iface);
+static void e_contact_store_tree_model_init (GtkTreeModelIface *iface);
+
+G_DEFINE_TYPE_EXTENDED (EContactStore, e_contact_store, G_TYPE_OBJECT, 0,
+	G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL, e_contact_store_tree_model_init))
+
 static void         e_contact_store_finalize        (GObject            *object);
 static GtkTreeModelFlags e_contact_store_get_flags       (GtkTreeModel       *tree_model);
 static gint         e_contact_store_get_n_columns   (GtkTreeModel       *tree_model);
@@ -92,42 +94,6 @@ static void stop_view             (EContactStore *contact_store, EBookView *view
 
 static GObjectClass *parent_class = NULL;
 
-GType
-e_contact_store_get_type (void)
-{
-	static GType contact_store_type = 0;
-
-	if (!contact_store_type) {
-		static const GTypeInfo contact_store_info =
-		{
-			sizeof (EContactStoreClass),
-			NULL,		/* base_init */
-			NULL,		/* base_finalize */
-			(GClassInitFunc) e_contact_store_class_init,
-			NULL,		/* class_finalize */
-			NULL,		/* class_data */
-			sizeof (EContactStore),
-			0,
-			(GInstanceInitFunc) e_contact_store_init,
-		};
-
-		static const GInterfaceInfo tree_model_info =
-		{
-			(GInterfaceInitFunc) e_contact_store_tree_model_init,
-			NULL,
-			NULL
-		};
-
-		contact_store_type = g_type_register_static (G_TYPE_OBJECT, "EContactStore",
-							     &contact_store_info, 0);
-		g_type_add_interface_static (contact_store_type,
-					     GTK_TYPE_TREE_MODEL,
-					     &tree_model_info);
-	}
-
-	return contact_store_type;
-}
-
 static void
 e_contact_store_class_init (EContactStoreClass *class)
 {
@@ -194,7 +160,7 @@ e_contact_store_finalize (GObject *object)
  *
  * Creates a new #EContactStore.
  *
- * Return value: A new #EContactStore.
+ * Returns: A new #EContactStore.
  **/
 EContactStore *
 e_contact_store_new (void)
@@ -799,7 +765,7 @@ query_contact_source (EContactStore *contact_store, ContactSource *source)
  *
  * Gets the #EBook that provided the contact at @iter.
  *
- * Return value: An #EBook.
+ * Returns: An #EBook.
  **/
 EBook *
 e_contact_store_get_book (EContactStore *contact_store, GtkTreeIter *iter)
@@ -821,7 +787,7 @@ e_contact_store_get_book (EContactStore *contact_store, GtkTreeIter *iter)
  *
  * Gets the #EContact at @iter.
  *
- * Return value: An #EContact.
+ * Returns: An #EContact.
  **/
 EContact *
 e_contact_store_get_contact (EContactStore *contact_store, GtkTreeIter *iter)
@@ -844,7 +810,7 @@ e_contact_store_get_contact (EContactStore *contact_store, GtkTreeIter *iter)
  *
  * Sets @iter to point to the contact row matching @uid.
  *
- * Return value: %TRUE if the contact was found, and @iter was set. %FALSE otherwise.
+ * Returns: %TRUE if the contact was found, and @iter was set. %FALSE otherwise.
  **/
 gboolean
 e_contact_store_find_contact (EContactStore *contact_store, const gchar *uid,
@@ -869,7 +835,7 @@ e_contact_store_find_contact (EContactStore *contact_store, const gchar *uid,
  *
  * Gets the list of books that provide contacts for @contact_store.
  *
- * Return value: A #GList of pointers to #EBook. The caller owns the list,
+ * Returns: A #GList of pointers to #EBook. The caller owns the list,
  * but not the books.
  **/
 GList *
@@ -993,7 +959,7 @@ e_contact_store_set_query (EContactStore *contact_store, EBookQuery *book_query)
  * Gets the query that's being used to fetch contacts from the books
  * assigned to @contact_store.
  *
- * Return value: The #EBookQuery being used.
+ * Returns: The #EBookQuery being used.
  **/
 EBookQuery *
 e_contact_store_peek_query (EContactStore *contact_store)
